@@ -7,41 +7,37 @@
 # You may use and distribute this software under the same terms and conditions
 # as Perl itself.
 
-package
-    PkgConfig::Vars;
+package PkgConfig::Vars;
 # this is a namespace for .pc files to hold their variables without
 # relying on lexical scope.
 
-package
-    PkgConfig::UDefs;
+package PkgConfig::UDefs;
 # This namespace provides user-defined variables which are to override any
 # declarations within the .pc file itself.
 
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.08320_03';
+our $VERSION = '0.05020';
+
+require 5.005;
 
 use strict;
 use warnings;
-use 5.006;
-use Config;
 use File::Spec;
-use File::Glob 'bsd_glob';
+use Getopt::Long;
 use Class::Struct; #in core since 5.004
-use Data::Dumper;
-use File::Basename qw( dirname );
-use Text::ParseWords qw( shellwords );
-
 our $UseDebugging;
 
+use Data::Dumper;
+
 ################################################################################
 ### Check for Log::Fu                                                        ###
 ################################################################################
 BEGIN {
-    my $ret = eval q{
-        use Log::Fu 0.25 { level => "warn" };
-        1;
+    my $ret = eval {
+        require Log::Fu;
+        Log::Fu->import({level => "warn"}); 1;
     };
     
     if(!$ret) {
@@ -63,155 +59,14 @@ our $VarClassSerial = 0;
 ### Sane Defaults                                                            ###
 ################################################################################
 our @DEFAULT_SEARCH_PATH = qw(
-    /usr/local/lib/pkgconfig /usr/local/share/pkgconfig
     /usr/lib/pkgconfig /usr/share/pkgconfig
+    /usr/local/lib/pkgconfig /usr/local/share/pkgconfig
 
 );
 
-if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
+my @ENV_SEARCH_PATH = split(/:/, $ENV{PKG_CONFIG_PATH} || "");
 
-    # use the defaults regardless of detected platform
-
-} elsif($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
-
-    my $arch;
-    if(-x "/usr/bin/dpkg-architecture") {
-        # works if dpkg-dev is installed
-        # rt96694
-        ($arch) = map { chomp; (split /=/)[1] }
-                  grep /^DEB_HOST_MULTIARCH=/,
-                  `/usr/bin/dpkg-architecture`;
-    } elsif(-x "/usr/bin/gcc") {
-        # works if gcc is installed
-        $arch = `/usr/bin/gcc -dumpmachine`;
-        chomp $arch;
-    } else {
-        my $deb_arch = `dpkg --print-architecture`;
-        if($deb_arch =~ /^amd64/) {
-            if($^O eq 'linux') {
-                $arch = 'x86_64-linux-gnu';
-            } elsif($^O eq 'gnukfreebsd') {
-                $arch = 'x86_64-kfreebsd-gnu';
-            }
-        } elsif($deb_arch =~ /^i386/) {
-            if($^O eq 'linux') {
-                $arch = 'i386-linux-gnu';
-            } elsif($^O eq 'gnukfreebsd') {
-                $arch = 'i386-kfreebsd-gnu';
-            }
-        }
-    }
-
-    if($arch) {
-        if(scalar grep /--print-foreign-architectures/, `dpkg --help`)
-        {
-            # multi arch support / Debian 7+
-            @DEFAULT_SEARCH_PATH = (
-                "/usr/local/lib/$arch/pkgconfig",
-                "/usr/local/lib/pkgconfig",
-                "/usr/local/share/pkgconfig",
-                "/usr/lib/$arch/pkgconfig",
-                "/usr/lib/pkgconfig",
-                "/usr/share/pkgconfig",
-            );
-        } else {
-        
-            @DEFAULT_SEARCH_PATH = (
-                "/usr/local/lib/pkgconfig",
-                "/usr/local/lib/pkgconfig/$arch",
-                "/usr/local/share/pkgconfig",
-                "/usr/lib/pkgconfig",
-                "/usr/lib/pkgconfig/$arch",
-                "/usr/share/pkgconfig",
-            );
-        }
-    
-    } else {
-
-        @DEFAULT_SEARCH_PATH = (
-            "/usr/local/lib/pkgconfig",
-            "/usr/local/share/pkgconfig",
-            "/usr/lib/pkgconfig",
-            "/usr/share/pkgconfig",
-        );
-
-    }
-    
-} elsif($^O eq 'linux' && -r "/etc/redhat-release") {
-
-    if(-d "/usr/lib64/pkgconfig") {
-        @DEFAULT_SEARCH_PATH = qw(
-            /usr/lib64/pkgconfig
-            /usr/share/pkgconfig
-        );
-    } else {
-        @DEFAULT_SEARCH_PATH = qw(
-            /usr/lib/pkgconfig
-            /usr/share/pkgconfig
-        );
-    }
-
-} elsif($^O eq 'freebsd') {
-
-    # TODO: FreeBSD 10's version of pkg-config does not
-    # support PKG_CONFIG_DEBUG_SPEW so I can't verify
-    # the path there, but this is what it is for
-    # FreeBSD 9
-    @DEFAULT_SEARCH_PATH = qw(
-        /usr/local/libdata/pkgconfig
-        /usr/local/lib/pkgconfig
-    );
-
-} elsif($^O eq 'netbsd') {
-
-    @DEFAULT_SEARCH_PATH = qw(
-        /usr/pkg/lib/pkgconfig
-        /usr/pkg/share/pkgconfig
-        /usr/X11R7/lib/pkgconfig
-        /usr/lib/pkgconfig
-    );
-} elsif($^O eq 'openbsd') {
-
-    @DEFAULT_SEARCH_PATH = qw(
-        /usr/lib/pkgconfig
-        /usr/local/lib/pkgconfig
-        /usr/local/share/pkgconfig
-        /usr/X11R6/lib/pkgconfig
-        /usr/X11R6/share/pkgconfig
-    );
-
-} elsif($^O eq 'MSWin32') {
-
-    # Caveats:
-    # 1. This pulls in Config,
-    #    which we don't load on non MSWin32
-    #    but it is in the core.
-    # 2. Slight semantic difference in that we are treating
-    #    Strawberry as the "system" rather than Windows, but
-    #    since pkg-config is rarely used in MSWin32, it is
-    #    better to have something that is useful rather than
-    #    worry about if it is exactly the same as other
-    #    platforms.
-    # 3. It is a little brittle in that Strawberry might 
-    #    one day change its layouts.  If it has and you are
-    #    reading this, please send a pull request or simply
-    #    let me know -plicease
-    require Config;
-    if($Config::Config{myuname} =~ /strawberry-perl/)
-    {
-        my($vol, $dir, $file) = File::Spec->splitpath($^X);
-        my @dirs = File::Spec->splitdir($dir);
-        splice @dirs, -3;
-        my $path = (File::Spec->catdir($vol, @dirs, qw( c lib pkgconfig )));
-        $path =~ s{\\}{/}g;
-        @DEFAULT_SEARCH_PATH = $path;
-    }
-
-}
-
-my @ENV_SEARCH_PATH = split($Config{path_sep}, $ENV{PKG_CONFIG_PATH} || "");
-
-unshift @DEFAULT_SEARCH_PATH, @ENV_SEARCH_PATH;
+push @DEFAULT_SEARCH_PATH, @ENV_SEARCH_PATH;
 
 our @DEFAULT_EXCLUDE_CFLAGS = qw(-I/usr/include -I/usr/local/include);
 # don't include default link/search paths!
@@ -223,53 +78,6 @@ our @DEFAULT_EXCLUDE_LFLAGS = qw(
     -R/lib -R/usr/lib -R/usr/lib64 -R/lib32 -R/lib64 -R/usr/local/lib
 );
 
-if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
-
-    # use the defaults regardless of detected platform
-
-} elsif($^O eq 'MSWin32') {
-
-    if($Config::Config{cc} =~ /cl(\.exe)?$/i)
-    {
-        @DEFAULT_EXCLUDE_LFLAGS = ();
-        @DEFAULT_EXCLUDE_CFLAGS = ();
-    }
-    else
-    {
-        @DEFAULT_EXCLUDE_LFLAGS = (
-            "-L/mingw/lib",
-            "-R/mingw/lib",
-            "-L/mingw/lib/pkgconfig/../../lib",
-            "-R/mingw/lib/pkgconfig/../../lib",
-        );
-        @DEFAULT_EXCLUDE_CFLAGS = (
-            "-I/mingw/include",
-            "-I/mingw/lib/pkgconfig/../../include",
-        );
-    }
-    
-    # See caveats above for Strawberry
-    require Config;
-    if($Config::Config{myuname} =~ /strawberry-perl/)
-    {
-        my($vol, $dir, $file) = File::Spec->splitpath($^X);
-        my @dirs = File::Spec->splitdir($dir);
-        splice @dirs, -3;
-        my $path = (File::Spec->catdir($vol, @dirs, qw( c )));
-        $path =~ s{\\}{/}g;
-        push @DEFAULT_EXCLUDE_LFLAGS, (
-            "-L$path/lib",
-            "-L$path/lib/pkgconfig/../../lib",
-            "-R$path/lib",
-            "-R$path/lib/pkgconfig/../../lib",
-        );
-        push @DEFAULT_EXCLUDE_CFLAGS, (
-            "-I$path/include",
-            "-I$path/lib/pkgconfig/../../include",
-        );
-    }
-}
-
 
 my $LD_OUTPUT_RE = qr/
     SEARCH_DIR\("
@@ -373,13 +181,8 @@ struct(
      
      # options for printing variables
      'print_variables' => '$',
-     'print_variable' => '$',
      'print_values' => '$',
      'defined_variables' => '*%',
-     
-     # for creating PkgConfig objects with identical
-     # settings
-     'original' => '$',
     ]
 );
 
@@ -391,12 +194,12 @@ struct(
 
 sub _get_pc_varname {
     my ($self,$vname_base) = @_;
-    $self->varclass . "::" . $vname_base;
+    return $self->varclass . "::" . $vname_base;
 }
 
 sub _get_pc_udefname {
     my ($self,$vname_base) = @_;
-    $self->udefclass . "::" . $vname_base;
+    return $self->udefclass . "::" . $vname_base;
 }
 
 sub _pc_var {
@@ -405,11 +208,9 @@ sub _pc_var {
     no strict 'refs';
     $vname = $self->_get_pc_varname($vname);
     my $glob = *{$vname};
-    $glob ? $$glob : ();
-}
-
-sub _quote_cvt($)  {
-    join ' ', map { s/(\s|"|')/\\$1/g; $_ } shellwords(shift)
+    return unless $glob;
+    
+    return $$glob;
 }
 
 sub assign_var {
@@ -421,14 +222,11 @@ sub assign_var {
         log_debug("Prefix already defined by user");
         return;
     }
-    my $evalstr = sprintf('$%s = PkgConfig::_quote_cvt(%s)',
+    my $evalstr = sprintf('$%s = %s',
                     $self->_get_pc_varname($field), $value);
     
     log_debug("EVAL", $evalstr);
-    do {
-        no warnings 'uninitialized';
-        eval $evalstr;
-    };
+    eval $evalstr;
     if($@) {
         log_err($@);
     }
@@ -461,8 +259,6 @@ sub find {
         ['exclude_cflags', \@DEFAULT_EXCLUDE_CFLAGS]
     );
     
-    my %original = %options;
-    
     foreach (@uspecs) {
         my ($basekey,$default) = @$_;
         my $list = [ @{$options{$basekey} ||= [] } ];
@@ -479,7 +275,6 @@ sub find {
     $VarClassSerial++;
     $options{varclass} = sprintf("PkgConfig::Vars::SERIAL_%d", $VarClassSerial);
     $options{udefclass} = sprintf("PkgConfig::UDefs::SERIAL_%d", $VarClassSerial);
-    $options{original} = \%original;
     
     
     my $udefs = delete $options{VARS} || {};
@@ -499,37 +294,12 @@ sub find {
         @libraries = ($library);
     }
     
-    if($options{file_path}) {
-    
-        if(-r $options{file_path}) {
-            $o->recursion(1);
-            $o->parse_pcfile($options{file_path});
-            $o->recursion(0);
-        } else {
-            $o->errmsg("No such file $options{file_path}\n");
-        }
-    
-    } else {
-    
-        foreach my $lib (@libraries) {
-            $o->recursion(0);
-            my($op,$ver);
-            ($lib,$op,$ver) = ($1,$2,PkgConfig::Version->new($3))
-                if $lib =~ /^(.*)\s+(!=|=|>=|<=|>|<)\s+(.*)$/;
-            $o->find_pcfile($lib);
-            
-            if(!$o->errmsg && defined $op) {
-                $op = '==' if $op eq '=';
-                unless(eval qq{ PkgConfig::Version->new(\$o->pkg_version) $op \$ver })
-                {
-                    $o->errmsg("Requested '$lib $op $ver' but version of $lib is " . 
-                        ($o->pkg_version ? $o->pkg_version : '') . "\n");
-                }
-            }
-        }
+    foreach my $lib (@libraries) {
+        $o->recursion(0);
+        $o->find_pcfile($lib);
     }
     
-    $o;
+    return $o;
 }
 
 ################################################################################
@@ -610,14 +380,14 @@ sub get_requires {
         }
     }
     #log_debug(@ret);
-    @ret;
+    return @ret;
 }
 
 
 sub parse_line {
     my ($self,$line,$evals) = @_;
     no strict 'vars';
-
+    
     $line =~ s/#[^#]+$//g; # strip comments
     return unless $line;
     
@@ -638,11 +408,12 @@ sub parse_line {
 
     log_debugf("Field %s, Value %s", $field, $value);
     
-    $field = lc($field);
-    
     #perl variables can't have '.' in them:
     $field =~ s/\./DOT/g;
     
+    
+    $field = lc($field);
+    
     #remove quoutes from field names
     $field =~ s/['"]//g;
     
@@ -658,17 +429,14 @@ sub parse_line {
     
     $value =~ s/\$\{/\$\{$varclass\::/g;
     
-    # preserve quoted space
-    $value = join ' ', map { s/(["'])/\\$1/g; "'$_'" } shellwords $value
-      if $value =~ /[\\"']/;
-    
     #quoute the value string, unless quouted already
-    $value = "\"$value\"";
+    $value = "\"$value\"" unless $value =~ /^["']/;
     
     #get existent variables from our hash:
     
     
-    #$value =~ s/'/"/g; #allow for interpolation
+    $value =~ s/'/"/g; #allow for interpolation
+    
     $self->assign_var($field, $value);
     
 }
@@ -691,10 +459,7 @@ sub parse_pcfile {
     
     #Fold lines:
     
-    my $pcfiledir = dirname $pcfile;
-    $pcfiledir =~ s{\\}{/}g;
-
-    foreach my $line ("pcfiledir=$pcfiledir", @lines) {
+    foreach my $line (@lines) {
         $self->parse_line($line, \@eval_strings);
     }
     
@@ -724,18 +489,11 @@ sub parse_pcfile {
         $self->pkg_description( $self->_pc_var('description') );
         $self->pkg_exists(1);        
     }
-
+    
     unless ($self->no_recurse) {
         foreach (@deps) {
             my ($dep,$cmp_op,$version) = @$_;
-            $dep = "$dep $cmp_op $version" if defined $cmp_op;
-            my $other = PkgConfig->find($dep, %{ $self->original });
-            if($other->errmsg) {
-                $self->errmsg($other->errmsg);
-                last;
-            }
-            $self->append_cflags(  $other->get_cflags );
-            $self->append_ldflags( $other->get_ldflags );
+            $self->find_pcfile($dep);
         }
     }
 }
@@ -783,17 +541,13 @@ sub find_pcfile {
 ################################################################################
 ################################################################################
 
-sub _return_context (@) {
-    wantarray ? (@_) : join(' ', map { s/(\s|['"])/\\$1/g; $_ } @_)
-}
-
 sub get_cflags {
     my $self = shift;
     my @cflags = @{$self->cflags};
 
     filter_omit(\@cflags, $self->exclude_cflags);
     filter_dups(\@cflags);
-    _return_context @cflags;
+    return @cflags;
 }
 
 sub get_ldflags {
@@ -813,30 +567,9 @@ sub get_ldflags {
     @ret = reverse @ret;
     filter_dups(\@ret);
     @ret = reverse(@ret);
-    _return_context @ret;
+    return @ret;
 }
 
-sub get_var {
-    my($self, $name) = @_;
-    $self->_pc_var($name);
-}
-
-sub get_list {
-    my $self = shift;
-    my @search_paths = @{$self->search_path};
-    my @rv = ();
-    $self->recursion(0);
-    for my $d (@search_paths) {
-        next unless -d $d;
-        for my $pc (bsd_glob("$d/*.pc")) {
-            if ($pc =~ m|/([^\\\/]+)\.pc$|) {
-                $self->parse_pcfile($pc);
-                push @rv, [$1, $self->_pc_var('name') . ' - ' . $self->_pc_var('description')];
-            }
-        }
-    }
-    @rv;
-}
 
 
 ################################################################################
@@ -854,11 +587,10 @@ sub _split_flags {
     if(@flags == 1) {
         my $str = shift @flags;
         return () if !$str;
-        #@flags = map { s/\\(\s)/$1/g; $_ } split(/(?<!\\)\s+/, $str);
-        @flags = shellwords $str;
+        @flags = split(/\s+/, $str);
     }
     @flags = grep $_, @flags;
-    @flags;
+    return @flags;
 }
 
 
@@ -903,7 +635,7 @@ sub version_2_array {
         && $chunk =~ /^\d+$/) {
         push @ret, $chunk;
     }
-    @ret;
+    return @ret;
 }
 
 
@@ -921,7 +653,7 @@ sub version_check {
             return 0;
         }
     }
-    1;
+    return 1;
 }
 
 
@@ -929,34 +661,6 @@ if(caller) {
     return 1;
 }
 
-package
-    PkgConfig::Version;
-
-use overload
-    '<=>' => sub { $_[0]->cmp($_[1]) },
-    '""'  => sub { $_[0]->as_string },
-    fallback => 1;
-
-sub new {
-    my($class, $value) = @_;
-    bless [split /\./, defined $value ? $value : ''], $class;
-}
-
-sub clone {
-    __PACKAGE__->new(shift->as_string);
-}
-
-sub as_string {
-    my($self) = @_;
-    join '.', @{ $self };
-}
-
-sub cmp {
-    my($self, $other) = @_;
-    no warnings 'uninitialized';
-    defined($self->[0]) || defined($other->[0]) ? ($self->[0] <=> $other->[0]) || &cmp([@{$self}[1..$#$self]], [@{$other}[1..$#$other]]) : 0;
-}
-
 ################################################################################
 ################################################################################
 ################################################################################
@@ -969,7 +673,7 @@ sub cmp {
 package PkgConfig::Script;
 use strict;
 use warnings;
-use Getopt::Long qw(:config no_ignore_case);
+use Getopt::Long;
 use Pod::Usage;
 
 my $quiet_errors = 1;
@@ -989,17 +693,10 @@ my @POD_USAGE_OPTIONS = (
 
 GetOptions(
     'libs' => \my $PrintLibs,
-    'libs-only-L' => \my $PrintLibsOnlyL,
-    'libs-only-l' => \my $PrintLibsOnlyl,
-    'list-all' => \my $ListAll,
     'static' => \my $UseStatic,
     'cflags' => \my $PrintCflags,
-    'cflags-only-I' => \my $PrintCflagsOnlyI,
     'exists' => \my $PrintExists,
-    'atleast-version=s' => \my $AtLeastVersion,
-    'exact-version=s'   => \my $ExactVersion,
-    'max-version=s'     => \my $MaxVersion,
-
+    
     'silence-errors' => \my $SilenceErrors,
     'print-errors' => \my $PrintErrors,
     
@@ -1007,7 +704,7 @@ GetOptions(
     
     'print-variables' => \my $PrintVariables,
     'print-values'  => \my $PrintValues,
-    'variable=s',   => \my $OutputVariableValue,
+    'variable=s',   => \my %OutputVariableValue,
     
     'modversion'    => \my $PrintVersion,
     'version',      => \my $PrintAPIversion,
@@ -1044,11 +741,13 @@ if($PrintAPIversion) {
 
 if($PrintRealVersion) {
 
-    printf STDOUT ("ppkg-config - cruftless pkg-config\n" .
+    printf STDOUT ("pkg-config.pl - cruftless pkg-config\n" .
             "Version: %s\n", $PkgConfig::VERSION);
     exit(0);
 }
 
+my @FINDLIBS = @ARGV or die "Must specify at least one library";
+
 if($PrintErrors) {
     $quiet_errors = 0;
 }
@@ -1056,14 +755,14 @@ if($SilenceErrors) {
     $quiet_errors = 1;
 }
 
-my $WantFlags = ($PrintCflags || $PrintLibs || $PrintLibsOnlyL || $PrintCflagsOnlyI || $PrintLibsOnlyl || $PrintVersion);
+my $WantFlags = ($PrintCflags || $PrintLibs || $PrintVersion);
 
 if($WantFlags) {
     $quiet_errors = 0 unless $SilenceErrors;
 }
 
 my %pc_options;
-if($PrintExists || $AtLeastVersion || $ExactVersion || $MaxVersion) {
+if($PrintExists) {
     $pc_options{no_recurse} = 1;
 }
 
@@ -1080,29 +779,6 @@ $pc_options{print_variables} = $PrintVariables;
 $pc_options{print_values} = $PrintValues;
 $pc_options{VARS} = \%UserVariables;
 
-if($ListAll) {
-    my $o = PkgConfig->find([], %pc_options);
-    my @list = $o->get_list();
-    
-    # can't use List::Util::max as it wasn't core until Perl 5.8
-    my $max_length = 0;
-    foreach my $length (map { length $_->[0] } @list) {
-        $max_length = $length if $length > $max_length;
-    }
-
-    printf "%-${max_length}s %s\n", $_->[0], $_->[1] for @list;
-    exit(0); 
-}
-
-my @FINDLIBS = @ARGV or die "Must specify at least one library";
-
-if($AtLeastVersion) {
-    @FINDLIBS = map { "$_ >= $AtLeastVersion" } @FINDLIBS;
-} elsif($MaxVersion) {
-    @FINDLIBS = map { "$_ <= $MaxVersion" } @FINDLIBS;
-} elsif($ExactVersion) {
-    @FINDLIBS = map { "$_ = $ExactVersion" } @FINDLIBS;
-}
 
 my $o = PkgConfig->find(\@FINDLIBS, %pc_options);
 
@@ -1122,11 +798,6 @@ if($o->print_variables) {
     }
 }
 
-if($OutputVariableValue) {
-    my $val = ($o->_pc_var($OutputVariableValue) or "");
-    print $val . "\n";
-}
-
 if(!$WantFlags) {
     exit(0);
 }
@@ -1136,31 +807,14 @@ if($PrintVersion) {
     exit(0);
 }
 
-my @print_flags;
-
 if($PrintCflags) {
-    @print_flags = $o->get_cflags;
-}
-
-if($PrintCflagsOnlyI) {
-    @print_flags = grep /^-I/, $o->get_cflags;
+    print join(" ", $o->get_cflags) . " ";
 }
 
 if($PrintLibs) {
-    @print_flags = $o->get_ldflags;
+    print join(" ", $o->get_ldflags) . " ";
 }
 
-# handle --libs-only-L and --libs-only-l but watch the case when
-# we got 'ppkg-config --libs-only-L --libs-only-l foo' which must behave just like
-# 'ppkg-config --libs-only-l foo'
-
-if($PrintLibsOnlyl or ($PrintLibsOnlyl and $PrintLibsOnlyL)) {
-    @print_flags = grep /^-l/, $o->get_ldflags;
-} elsif ($PrintLibsOnlyL) {
-    @print_flags = grep /^-[LR]/, $o->get_ldflags;
-}
-
-print scalar PkgConfig::_return_context(@print_flags);
 print "\n";
 exit(0);
 
@@ -1168,22 +822,27 @@ __END__
 
 =head1 NAME
 
-PkgConfig - Pure-Perl Core-Only replacement for pkg-config
+PkgConfig - Pure-Perl Core-Only replacement for C<pkg-config>
+
+=head1 NOTE
+
+The script is not actually installed yet (i haven't settled on a good name), but
+will decide based on input in a future version.
+
+Additionally, some dependencies are superficially included for debugging, and
+will be sanitized in a future 'release/stable' version.
 
 =head1 SYNOPSIS
 
 =head2 As a replacement for C<pkg-config>
 
-    $ ppkg-config --libs --cflags --static gio-2.0
+    $ pkg-config.pl --libs --cflags --static gio-2.0
 
     #outputs (lines artifically broken up for readability):
     # -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include
     # -pthread -lgio-2.0 -lz -lresolv -lgobject-2.0
     # -lgmodule-2.0 -ldl -lgthread-2.0 -pthread -lrt -lglib-2.0
 
-C<pkg-config.pl> can be used as an alias for C<ppkg-config> on platforms that
-support it.  It can also be installed as C<pkg-config> though this is not
-recomended if your system has a native C<pkg-config>.
 
 Compare to:
     $ pkg-config --libs --cflags --static gio-2.0
@@ -1202,7 +861,6 @@ Compare to:
     if($o->errmsg) {
         #handle error
     } else {
-        my $prefix = $o->get_var('prefix');
         my @cflags = $o->get_cflags;
         my @ldflags = $o->get_ldflags;
     }
@@ -1216,7 +874,7 @@ This is not a description of the uses of C<pkg-config> but rather a description
 of the differences between the C version and the Perl one.
 
 While C<pkg-config> is a compiled binary linked with glib, the pure-perl version
-has no such requirement, and will run wherever Perl ( >= 5.6 ) does.
+has no such requirement, and will run wherever Perl ( >= 5.04 ) does.
 
 The main supported options are the common C<--libs>, C<--cflags>,
 C<--static>, C<--exists> and C<--modversion>.
@@ -1239,30 +897,10 @@ The output should normally be suitable for passing to your favorite compiler.
 (Also) print linker flags. Dependencies are traverse in order. Top-level dependencies
 will appear earlier in the command line than bottom-level dependencies.
 
-=head4 --libs-only-L
-
-Prints -L/-R part of "--libs". It defines library search path but without libraries to link with.
-
-=head4 --libs-only-l
-
-Prints the -l part of "--libs".
-
-=head4 --list-all
-
-List all know packages.
-
 =head4 --cflags
 
 (Also) print compiler and C preprocessor flags.
 
-=head4 --cflags-only-I
-
-Prints the -I part of "--cflags"
-
-=head4 --modversion
-
-Print the version of a given package.
-
 =head4 --static
 
 Use extra dependencies and libraries if linking against a static version of the
@@ -1294,14 +932,12 @@ paths will be excluded from explicit -L and -I flags.
 Define a variable, overriding any such variable definition in the .pc file, and
 allowing your value to interpolate with subsequent uses.
 
-=head4 --variable=VARIABLE
-
-This returns the value of a variable defined in a package's .pc file.
-
 =head4 --print-variables
 
 Print all defined variables found in the .pc files.
 
+
+
 =head4 --version
 
 The target version of C<pkg-config> emulated by this script
@@ -1328,8 +964,8 @@ C<--silence-errors>
 
 =head3 ENVIRONMENT
 
-the C<PKG_CONFIG_PATH> variable is honored and used as a colon-delimited 
-(semicolon-delimited on Windows) list of directories with contain C<.pc> files.
+the C<PKG_CONFIG_PATH> variable is honored and used as a colon-delimited list
+of directories with contain C<.pc> files.
 
 =head2 MODULE OPTIONS
 
@@ -1353,13 +989,7 @@ recognized:
 Prepend search paths in addition to the paths specified in C<$ENV{PKG_CONFIG_PATH}>
 The value is an array reference.
 
-the C<_override> variant ignores defaults (like C<PKG_CONFIG_PATH>).
-
-=item C<file_path>
-
-Specifies the full path of the of the .pc file that you wish to load.  It does
-not need to be in the search path (although any dependencies will need to be).
-Useful if you know the full path of the exact .pc file that you want.
+the C<_override> variant ignores defaults (like c<PKG_CONFIG_PATH).
 
 =item C<exclude_cflags>
 
@@ -1369,6 +999,7 @@ Useful if you know the full path of the exact .pc file that you want.
 
 =item C<exclude_ldflags_override>
 
+
 Some C<.pc> files specify default compiler and linker search paths, e.g.
 C<-I/usr/include -L/usr/lib>. Specifying them on the command line can be
 problematic as it drastically changes the search order.
@@ -1414,19 +1045,7 @@ The version of the package
 
 =head4 I<< $o->get_ldflags >>
 
-Returns compiler and linker flags, respectively.
-
-In list context, these methods return a list with each argument split on
-unescaped spaces.
-
-In list context returns a list of compiler and linker flags, respectively.
-
-In scalar context returns a string of compiler and linker flags with spaces
-and quotes escaped correctly.
-
-=head4 I<< $o->get_var($name) >>
-
-Get the variable with the given name.
+Returns a list of compiler and linker flags, respectively.
 
 =head4 I<< PkgConfig->Guess >>
 
@@ -1435,75 +1054,13 @@ paths with those discovered by invoking L<ld(1)> and L<cpp(1)>.
 
 Currently this only works with GCC-supplied C<ld> and GNU C<ld>.
 
-=head2 INSTALL
-
-The C<Makefile.PL> that comes with C<PkgConfig> can take one or more C<--script>
-options to change of the name of the script or scripts that are installed.
-
-=over 4
-
-=item --script ppkg-config
-
-This is the default and works on all platforms
-
-=item --script pkg-config.pl
-
-This is installed by default on all platforms except for Windows, where the .pl
-may confuse the shell and cause the script to be opened in a text editor.
-
-=item --script pkg-config
-
-This is the default name of the real C<pkg-config> and so you have to specifically
-enable it if you want it.
-
-=item --script none
-
-Don't install any scripts.
-
-=back
-
-Example, install all script names:
-
- % perl Makefile.PL --script ppkg-config --script pkg-config.pl --script pkg-config
-
-Example, don't install any scripts:
-
- % perl Makefile.PL --script none
-
-You can also set the environment variable PERL_PKG_CONFIG_SCRIPTS to the
-desired --script value (separating each script name with a comma C<,>) to
-ensure that upgrades of PkgConfig do the same.
-
-=head2 CAVEATS
-
-On Strawberry Perl C<ppkg-config> acts like Strawberry is the system.  
-This means that
-
-=over 4
-
-=item
-
-The .pc files that are bundled with Strawberry are searched by default.
-
-=item
-
-The Strawberry include and lib directories are used to compute the 
-exclusion lists.
-
-=back
-
-As of Strawberry 5.20.0.1 PkgConfig is bundled with Strawberry and 
-C<pkg-config> is installed by default (in addition to C<ppkg-config>,
-though the C<ppkg-config> alias is NOT bundled with Strawberry itself).
-
-For details on how to patch the .pc files bundled with older Strawberries,
-see the C<README.win32> that comes with this Distribution.
-
 =head2 BUGS
 
 The order of the flags is not exactly matching to that of C<pkg-config>. From my
 own observation, it seems this module does a better job, but I might be wrong.
 
+Version checking is not yet implemented.
+
 Unlike C<pkg-config>, the scripts C<--exists> function will return nonzero if
 a package B<or> any of its dependencies are missing. This differs from the
 behavior of C<pkg-config> which will just check for the definition of the
@@ -1511,62 +1068,13 @@ package itself (without dependencies).
 
 =head1 SEE ALSO
 
-=over 4
+L<ExtUtils::PkgConfig>, a wrapper around the C<pkg-config> binary
 
-=item L<pkg-config|http://www.freedesktop.org/wiki/Software/pkg-config>
+L<pkg-config|http://www.freedesktop.org/wiki/Software/pkg-config>
 
-The original C implementation
-
-=item L<ExtUtils::PkgConfig>
-
-A wrapper around the C<pkg-config> binary that can be used in your C<Makefile.PL>
-or C<Build.PL>.
-
-=item L<http://www.openbsd.org/cgi-bin/cvsweb/src/usr.bin/pkg-config/>
-
-Another perl implementation of pkg-config
-
-=item L<pkgconf|https://github.com/pkgconf/pkgconf>
-
-An alternative C implementation
-
-=item L<pkg-config|https://github.com/ruby-gnome2/pkg-config>
-
-Pure Ruby implementation.
-
-=item L<pykg-config|https://pypi.python.org/pypi/pykg-config/1.2.0>
-
-A Python implementation.
-
-=back
-
-=head1 AUTHOR
-
-=over 4
-
-=item Original Author: M. Nunberg
-
-=item Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-=back
-
-Other contributors include:
-
-=over 4
-
-=item Vladimir Timofeev (vovkasm)
-
-=item kmx
-
-=item Sanel Zukan
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
+=head1 AUTHOR & COPYRIGHT
 
 Copyright (C) 2012 M. Nunberg
 
-This is free software; you can redistribute it and/or modify it under the same
-terms as the Perl 5 programming language system itself.
-
-=cut
+You may use and distribute this software under the same terms and conditions as
+Perl itself.
