@@ -2,20 +2,17 @@
 package PkgConfigTest;
 use strict;
 use warnings;
-use Config;
 use Test::More;
 use File::Basename;
+use Dir::Self qw(:static);
 use Data::Dumper;
-use Archive::Tar;
+use Archive::Extract;
 use File::Spec;
 use File::Basename qw(fileparse);
 use Config;
-use Cwd qw( cwd chdir );
-use FindBin ();
-use Exporter;
-our @ISA = qw( Exporter );
+use base qw(Exporter);
 
-$ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION} = 1;
+use Fcntl qw(LOCK_EX LOCK_UN LOCK_SH LOCK_NB);
 
 our @EXPORT = qw(
     expect_flags run_common $RV $S);
@@ -25,32 +22,25 @@ my @PC_PATHS = qw(usr/lib/pkgconfig usr/share/pkgconfig
                 
 
 
-my $TARBALL = File::Spec->catfile($FindBin::Bin, 'pc_files.tar.gz');
-my $LOCK    = File::Spec->catfile($FindBin::Bin, 'pc_files.lock');
-@PC_PATHS = map { $FindBin::Bin . "/$_" } @PC_PATHS;
+my $TARBALL = File::Spec->catfile(__DIR__, 'pc_files.tar.gz');
+@PC_PATHS = map { __DIR__ . "/$_" } @PC_PATHS;
 @PC_PATHS = map {
     my @components = split(/\//, $_);
     $_ = File::Spec->catfile(@components);
     $_;
 } @PC_PATHS;
     
-note Dumper(\@PC_PATHS);
+print Dumper(\@PC_PATHS);
 
-$ENV{PKG_CONFIG_PATH} = join($Config{path_sep}, @PC_PATHS);
+$ENV{PKG_CONFIG_PATH} = join(":", @PC_PATHS);
 
 our $RV;
 our $S;
 
-my $SCRIPT = $FindBin::Bin . "/../script/ppkg-config";
-
-# Work around git on windows' lamentable lack of symbolic
-# link support
-$SCRIPT = $FindBin::Bin . "/../lib/PkgConfig.pm"
-    if $^O eq 'MSWin32' && -d '.git';
-
+my $SCRIPT = __DIR__ . "/../script/pkg-config.pl";
 sub run_common {
     my @args = @_;
-    (my $ret = qx($^X $SCRIPT --env-only @args))
+    (my $ret = qx($SCRIPT --env-only @args))
         =~ s/(?:^\s+)|($?:\s+$)//g;
     $RV = $?;
     $S = $ret;
@@ -61,25 +51,53 @@ sub expect_flags {
     like($S, qr/\Q$flags\E/, $msg);
 }
 
+# For concurrency, it is necessary to maintain a lock here. The
+# lock should remain in place
+sub extract_our_tarball
+{
+    open my $fh, "+<", $TARBALL or die "$TARBALL: $!";
+    my $extract_dir = File::Spec->catfile(__DIR__, 'usr');
+    my $lock_status = flock($fh, LOCK_SH); # Block.
+    
+    # If we have a shared lock, let us check if the directory exists:
+    if (-d $extract_dir) {
+        return;
+    }
+    
+    # Now, let's try to get an exclusive lock. The process to get such a lock
+    # will be the one to extract the tarball:
+    $lock_status = flock($fh, LOCK_EX|LOCK_NB);
+    if (!$lock_status) {
+        flock($fh, LOCK_UN);
+        # Another process is extracting it. Wait until it's done.
+        goto &extract_our_tarball;
+    }
+    my $ae = Archive::Extract->new(archive => $TARBALL);
+    $ae->extract(to => __DIR__);
+}
+
+sub import {
+    extract_our_tarball();
+    goto &Exporter::import;
+}
+
 sub get_my_file_list {
-    plan skip_all => 'skip long running tests on ActiveState PPM build'
-      if $ENV{ACTIVESTATE_PPM_BUILD};
     my $pmfile = shift;
     my $needed = fileparse($pmfile, ".pm",".t");
     ($needed) = ($needed =~ /(FLIST.+)/);
     die "Invalid file $pmfile" unless $needed;
-    my $file_list = File::Spec->catfile($FindBin::Bin, $needed);
+    my $file_list = File::Spec->catfile(__DIR__, $needed);
     open my $fh, "<", $file_list or die "$file_list: $!";
-    note $file_list;
+    diag $file_list;
     my @lines = <$fh>;
     @lines = map { $_ =~ s/\s+$//g; $_ } @lines;
-    @lines = map { File::Spec->catfile($FindBin::Bin, $_) } @lines;
+    @lines = map { File::Spec->catfile(__DIR__, $_) } @lines;
     return \@lines;
 }
 
 sub run_exists_test {
     my ($flist,$pmfile) = @_;
-    note "$pmfile: Will perform --exist tests";
+    diag "$pmfile: Will perform --exist tests";
     foreach my $fname (@$flist) {
         next unless -f $fname;
         my ($base) = fileparse($fname, ".pc");
@@ -99,15 +117,15 @@ sub _single_flags_test {
             
             #these files define $prefix, but don't actually use them for
             #flags:
-            if($base =~ /^(?:glu?|libconfig)$/) {
-                note "Skipping gl pcfiles which define but do not use 'prefix'";
+            if($base =~ /^(?:glu?)$/) {
+                diag("Skipping gl pcfiles which define but do not use 'prefix'");
                 return;
             }
             
             #Check the file, see if it at all has a '$prefix'
             open my $fh, "<", $fname;
             if(!defined $fh) {
-                note "$fname: $!";
+                diag "$fname: $!";
                 return;
             }
             
@@ -115,7 +133,7 @@ sub _single_flags_test {
             if(grep /\$\{prefix\}/, @lines) {
                 ok(0, "Expected substituted prefix for $base");
             } else {
-                note "File $fname has no \${prefix} directive";
+                diag "File $fname has no \${prefix} directive";
             }
             return;
         }
@@ -125,10 +143,10 @@ sub _single_flags_test {
 
 sub run_flags_test {
     my ($flist,$pmfile) = @_;
-    note "$pmfile: Will perform --prefix, --cflags, and --libs tests";
+    diag "$pmfile: Will perform --prefix, --cflags, and --libs tests";
     foreach my $fname (@$flist) {
         _single_flags_test($fname);
     }
 }
 
-1;
+1;
\ No newline at end of file
